@@ -13,7 +13,23 @@ from googleads import ad_manager, errors
 
 
 from .ServiceAccount import ServiceAccount
-from .Utils import ListHelper, FileHelper, GAM_VERSION, PYTZ_TIMEZONE, NETWORK_CODE, APP_NAME
+from .Utils import ListHelper
+
+PYTZ_TIMEZONE='UTC'
+AD_UNIT_VIEW = 'TOP_LEVEL'
+METRICS = ['TOTAL_CODE_SERVED_COUNT',
+           'AD_SERVER_IMPRESSIONS',
+           'AD_SERVER_CLICKS',
+           'ADSENSE_LINE_ITEM_LEVEL_IMPRESSIONS',
+           'ADSENSE_LINE_ITEM_LEVEL_CLICKS',
+           'TOTAL_LINE_ITEM_LEVEL_IMPRESSIONS',
+           'TOTAL_LINE_ITEM_LEVEL_CPM_AND_CPC_REVENUE']
+
+DIMENSIONS = ['DATE', 'AD_UNIT_NAME', 'CUSTOM_TARGETING_VALUE_ID']
+
+GAM_VERSION = "v202305"
+NETWORK_CODE = '5574'
+APP_NAME = 'AdManager'
 
 # region objects
 gam_adUnit = Dict[int, bool]
@@ -109,22 +125,23 @@ class GamClient(ad_manager.AdManagerClient):
 
 
 class Audience(GamClient):
-    service_name = 'AudienceSegmentService'
+    __service_name = 'AudienceSegmentService'
+
+    def __init__(self,
+                 app_name: str = APP_NAME,
+                 network_code:  str = NETWORK_CODE,
+                 gam_version: str = GAM_VERSION):
+        gam_client = GamClient(app_name=app_name,
+                               network_code=network_code)
+        self.__gam_service = gam_client.get_service(service_name=self.__service_name,
+                                                    gam_version=gam_version)
 
     def create(self, name, description, custom_targeting, pageviews: int = 1, recencydays: int = 1, membershipexpirationdays: int = 90, network_code=NETWORK_CODE):
         # Initialize appropriate services.
-        audience_service = GamClient(app_name=APP_NAME,
-                                     network_code=network_code,
-                                     service_name=self.service_name,
-                                     version=GAM_VERSION)
-        network_service = GamClient(app_name=APP_NAME,
-                                    network_code=network_code,
-                                    service_name='NetworkService',
-                                    version=GAM_VERSION)
-
+        network_service = Network(
+            app_name=APP_NAME, network_code=network_code)
         # Get the root ad unit ID used to target the entire network.
-        root_ad_unit_id = (
-            network_service.getCurrentNetwork()['effectiveRootAdUnitId'])
+        root_ad_unit_id = network_service.effectiveRootAdUnitId()
 
         # Create inventory targeting (pointed at root ad unit i.e. the whole network)
         inventory_targeting = {
@@ -132,16 +149,11 @@ class Audience(GamClient):
                 {'adUnitId': root_ad_unit_id}
             ]
         }
-
-        # Create the custom criteria set.
-        top_custom_criteria_set = custom_targeting
-
         # Create the audience segment rule.
         rule = {
             'inventoryRule': inventory_targeting,
             'customCriteriaRule': custom_targeting
         }
-
         # Create an audience segment.
         audience_segment = [
             {
@@ -154,9 +166,8 @@ class Audience(GamClient):
                 'rule': rule
             }
         ]
-
-        audience_segments = (
-            audience_service.createAudienceSegments(audience_segment))
+        audience_segments = self.__gam_service.createAudienceSegments(
+            audience_segment)
 
         for created_audience_segment in audience_segments:
             logging.info('An audience segment with ID "%s", name "%s", and type "%s" '
@@ -165,9 +176,6 @@ class Audience(GamClient):
                                            created_audience_segment['type']))
 
     def list(self):
-        # Initialize appropriate service.
-        audience_segment_service = self.GetService(
-            self.service_name, version=GAM_VERSION)
         # Create a statement to select audience segments.
         statement = (ad_manager.StatementBuilder(version=GAM_VERSION)
                      .Where('Type = :type')
@@ -178,7 +186,7 @@ class Audience(GamClient):
         while True:
             logging.info(
                 'getAudienceSegmentsByStatement:statement.offset:'+str(statement.offset))
-            response = audience_segment_service.getAudienceSegmentsByStatement(
+            response = self.__gam_service.getAudienceSegmentsByStatement(
                 statement.ToStatement())
             if 'results' in response and len(response['results']):
                 results = results+response['results']
@@ -189,10 +197,6 @@ class Audience(GamClient):
         return results
 
     def list_all(self):
-        # Initialize appropriate service.
-        audience_segment_service = self.GetService(service_name=self.service_name,
-                                                   version=GAM_VERSION)
-
         # Create a statement to select audience segments.
         statement = ad_manager.StatementBuilder(version=GAM_VERSION)
         results = []
@@ -200,15 +204,14 @@ class Audience(GamClient):
         # Retrieve a small amount of audience segments at a time, paging
         # through until all audience segments have been retrieved.
         while True:
-            response = audience_segment_service.getAudienceSegmentsByStatement(
+            response = self.__gam_service.getAudienceSegmentsByStatement(
                 statement.ToStatement())
             if 'results' in response and len(response['results']):
 
                 for audience_segment in response['results']:
-                    # Print out some information for each audience segment.
-                    print('Audience segment with ID "%d", name "%s", and size "%d" was '
-                          'found.\n' % (audience_segment['id'], audience_segment['name'],
-                                        audience_segment['size']))
+                    logging.info('Audience segment with ID "%d", name "%s", and size "%d" was '
+                                 'found.\n' % (audience_segment['id'], audience_segment['name'],
+                                               audience_segment['size']))
 
                 results = results+response['results']
                 statement.offset += statement.limit
@@ -217,11 +220,13 @@ class Audience(GamClient):
 
         return results
 
-    def update(self, audience_segment_id, name, description, custom_targeting_key_id, custom_targeting_value_id, pageviews=1, recencydays=1, membershipexpirationdays=90):
-        # Initialize appropriate service.
-        audience_segment_service = self.GetService(service_name=self.service_name,
-                                                   version=GAM_VERSION)
-
+    def update(self, audience_segment_id, name,
+               description,
+               custom_targeting_key_id,
+               custom_targeting_value_id,
+               pageviews=1,
+               recencydays=1,
+               membershipexpirationdays=90):
         # Create statement object to get the specified first party audience segment.
         statement = (ad_manager.StatementBuilder(version=GAM_VERSION)
                      .Where('Type = :type AND Id = :audience_segment_id')
@@ -231,35 +236,35 @@ class Audience(GamClient):
                      .Limit(1))
 
         # Get audience segments by statement.
-        response = audience_segment_service.getAudienceSegmentsByStatement(
+        response = self.__gam_service.getAudienceSegmentsByStatement(
             statement.ToStatement())
 
         if 'results' in response and len(response['results']):
             updated_audience_segments = []
             for audience_segment in response['results']:
-                print('Audience segment with id "%s" and name "%s" will be updated.'
-                      % (audience_segment['id'], audience_segment['name']))
+                audience_segment['name'] = name
+                audience_segment['description'] = description
 
                 audience_segment['membershipExpirationDays'] = membershipexpirationdays
                 updated_audience_segments.append(audience_segment)
 
-            audience_segments = audience_segment_service.updateAudienceSegments(
+            audience_segments = self.__gam_service.updateAudienceSegments(
                 updated_audience_segments)
 
             for audience_segment in audience_segments:
-                print('Audience segment with id "%s" and name "%s" was updated' %
-                      (audience_segment['id'], audience_segment['name']))
+                logging.info('Audience segment with id "%s" and name "%s" was updated' %
+                             (audience_segment['id'], audience_segment['name']))
         else:
-            print('No audience segment found to update.')
+            logging.info('No audience segment found to update.')
 
 
 class Network():
     __service_name: str = 'NetworkService'
 
     def __init__(self,
-                 app_name: Optional[str] = APP_NAME,
-                 network_code:  Optional[str] = NETWORK_CODE,
-                 gam_version: Optional[str] = GAM_VERSION):
+                 app_name: str = APP_NAME,
+                 network_code:  str = NETWORK_CODE,
+                 gam_version: str = GAM_VERSION):
         gam_client = GamClient(app_name=app_name,
                                network_code=network_code)
         self.__gam_service = gam_client.get_service(service_name=self.__service_name,
@@ -274,9 +279,9 @@ class CustomTargeting():
     __service_name = 'CustomTargetingService'
 
     def __init__(self,
-                 app_name: Optional[str] = APP_NAME,
-                 network_code:  Optional[str] = NETWORK_CODE,
-                 gam_version: Optional[str] = GAM_VERSION):
+                 app_name: str = APP_NAME,
+                 network_code:  str = NETWORK_CODE,
+                 gam_version: str = GAM_VERSION):
         gam_client = GamClient(app_name=app_name,
                                network_code=network_code)
         self.__gam_service = gam_client.get_service(service_name=self.__service_name,
@@ -352,9 +357,9 @@ class TargetingPreset():
     __service_name = 'TargetingPresetService'
 
     def __init__(self,
-                 app_name: Optional[str] = APP_NAME,
-                 network_code:  Optional[str] = NETWORK_CODE,
-                 gam_version: Optional[str] = GAM_VERSION):
+                 app_name: str = APP_NAME,
+                 network_code:  str = NETWORK_CODE,
+                 gam_version: str = GAM_VERSION):
         gam_client = GamClient(app_name=app_name,
                                network_code=network_code)
         self.__gam_service = gam_client.get_service(service_name=self.__service_name,
@@ -387,9 +392,9 @@ class Report():
     service_name = 'ReportService'
 
     def __init__(self,
-                 app_name: Optional[str] = APP_NAME,
-                 network_code:  Optional[str] = NETWORK_CODE,
-                 gam_version: Optional[str] = GAM_VERSION):
+                 app_name: str = APP_NAME,
+                 network_code:  str = NETWORK_CODE,
+                 gam_version: str = GAM_VERSION):
         gam_client = GamClient(app_name=app_name,
                                network_code=network_code)
         self.__gam_service = gam_client.get_service(service_name=self.service_name,
@@ -408,7 +413,7 @@ class Report():
             # Run the report and wait for it to finish.
             report_job_id = report_downloader.WaitForReport(report_job)
         except errors.AdManagerReportError as e:
-            print('Failed to generate report. Error was: %s' % e)
+            logging.error('Failed to generate report. Error was: %s' % e)
         logging.info('report generated')
         export_format = 'CSV_DUMP'
 
@@ -434,34 +439,32 @@ class Report():
         return report_data
 
     @staticmethod
-    def gen_report_statement(ad_units: Optional[List[int]] = None,
+    def gen_report_statement(ad_units: Optional[Union[int, List[int]]] = None,
                              targeting_value_ids: Optional[gam_targetingValues] = None,
-                             order_id: Optional[Union[int, List[int]]] = None,
-                             exclusion_targeting_value_ids: Optional[gam_targetingValues] = None,
-                             mobile_inventory_type: Optional[str] = None):
+                             order_id: Optional[Union[int, List[int]]] = None):
         logging.info('Report::gen_report_statement')
         where_conditions = []
         if ad_units is not None:
-            where_conditions.append(
-                f'PARENT_AD_UNIT_ID IN ({", ".join(str(value) for value in ad_units)})')
+            if type(ad_units) == list:
+                where_conditions.append(
+                    f'PARENT_AD_UNIT_ID IN ({", ".join(str(value) for value in ad_units)})')
+            elif type(ad_units) == int:
+                where_conditions.append(f'PARENT_AD_UNIT_ID IN ({ad_units}')
+
         if targeting_value_ids is not None:
             where_conditions.append(
                 f'CUSTOM_TARGETING_VALUE_ID  IN ({", ".join(str(value) for value in targeting_value_ids)})')
-        if exclusion_targeting_value_ids is not None:
-            where_conditions.append(
-                f'NOT CUSTOM_TARGETING_VALUE_ID  IN ({", ".join(str(value) for value in exclusion_targeting_value_ids)})')
-        if mobile_inventory_type is not None:
-            where_conditions.append(
-                f"MOBILE_INVENTORY_TYPE='{mobile_inventory_type}'")
+
         if order_id is not None:
             if type(order_id) == int:
-                order_id = [order_id]
-            where_conditions.append(
-                f'ORDER_ID IN ({",".join(str(value) for value in order_id)})')  # type: ignore
+                where_conditions.append(
+                    f'ORDER_ID IN ({order_id})')
+            elif type(order_id) == List[int]:
+                where_conditions.append(
+                    f'ORDER_ID IN ({",".join(str(value) for value in order_id)})')
         where_statement = " AND ".join(where_conditions)
         built_statement = (ad_manager.StatementBuilder(version=GAM_VERSION)
                            .Where(where_statement)
-                           # No limit or offset for reports # type: ignore
                            .Limit(0)
                            .Offset(None))
 
@@ -471,22 +474,10 @@ class Report():
     def gen_report_query(report_statement,
                          report_end: datetime.date = datetime.date.today(),
                          report_days: int = 7,
-                         dimensions: Optional[List[str]] = None,
-                         metrics: Optional[List[str]] = None,
-                         ad_unit_view: Optional[str] = 'TOP_LEVEL'):
+                         dimensions: List[str] = DIMENSIONS,
+                         metrics: List[str] = METRICS,
+                         ad_unit_view: str = AD_UNIT_VIEW):
         logging.info('api_build_report_query')
-        if dimensions is None:
-            dimensions = ['DATE', 'AD_UNIT_NAME', 'CUSTOM_TARGETING_VALUE_ID']
-        if metrics is None:
-            metrics = ['TOTAL_CODE_SERVED_COUNT',
-                       'AD_SERVER_IMPRESSIONS',
-                       'AD_SERVER_CLICKS',
-                       'ADSENSE_LINE_ITEM_LEVEL_IMPRESSIONS',
-                       'ADSENSE_LINE_ITEM_LEVEL_CLICKS',
-                       'TOTAL_LINE_ITEM_LEVEL_IMPRESSIONS',
-                       'TOTAL_LINE_ITEM_LEVEL_CPM_AND_CPC_REVENUE']
-        if ad_unit_view is None:
-            ad_unit_view = 'TOP_LEVEL'
 
         start_date = report_end - datetime.timedelta(days=report_days)
 
@@ -534,15 +525,13 @@ class Report():
                              targeting_value_ids: Optional[gam_targetingValues] = None,
                              report_date: datetime.date = datetime.date.today(),
                              days: int = 7,
-                             dimensions: Optional[List[str]] = None,
-                             metrics: Optional[List[str]] = None,
-                             ad_unit_view: Optional[str] = 'TOP_LEVEL',
-                             exclusion_targeting_value_ids: Optional[gam_targetingValues] = None,
-                             mobile_inventory_type: Optional[str] = None) -> pd.DataFrame:
+                             dimensions: List[str] = DIMENSIONS,
+                             metrics: List[str] = METRICS,
+                             ad_unit_view: str = AD_UNIT_VIEW) -> pd.DataFrame:
         if type(ad_units) == int:
             ad_units = [ad_units]
         statement = self.gen_report_statement(
-            ad_units=ad_units, targeting_value_ids=targeting_value_ids, exclusion_targeting_value_ids=exclusion_targeting_value_ids, mobile_inventory_type=mobile_inventory_type)
+            ad_units=ad_units, targeting_value_ids=targeting_value_ids)
         df = self.get_report_dataframe_by_statement(statement=statement,
                                                     report_date=report_date,
                                                     days=days,
@@ -555,9 +544,9 @@ class Report():
                                           statement,
                                           report_date: datetime.date = datetime.date.today(),
                                           days: int = 7,
-                                          dimensions: Optional[List[str]] = None,
-                                          metrics: Optional[List[str]] = None,
-                                          ad_unit_view: Optional[str] = 'TOP_LEVEL') -> pd.DataFrame:
+                                          dimensions: List[str] = DIMENSIONS,
+                                          metrics: List[str] = METRICS,
+                                          ad_unit_view: str = AD_UNIT_VIEW) -> pd.DataFrame:
         report_job = self.gen_report_query(statement,
                                            report_date,
                                            days,
@@ -575,9 +564,9 @@ class Forecast():
     service_name = 'ForecastService'
 
     def __init__(self,
-                 app_name: Optional[str] = APP_NAME,
-                 network_code:  Optional[str] = NETWORK_CODE,
-                 gam_version: Optional[str] = GAM_VERSION):
+                 app_name: str = APP_NAME,
+                 network_code:  str = NETWORK_CODE,
+                 gam_version: str = GAM_VERSION):
         gam_client = GamClient(app_name=app_name,
                                network_code=network_code)
         self.__gam_service = gam_client.get_service(service_name=self.service_name,
@@ -627,8 +616,10 @@ class Forecast():
         return prospective_line_item
 
     @staticmethod
-    def __gen_forecast_options(targets_list, report_date: datetime.datetime = datetime.datetime.now(
-            tz=pytz.timezone(PYTZ_TIMEZONE)), days: int = 30):
+    def __gen_forecast_options(targets_list,
+                               report_date: datetime.datetime = datetime.datetime.now(
+                                   tz=pytz.timezone(PYTZ_TIMEZONE)),
+                               days: int = 30):
         logging.info('Forecast::__gen_forecast_options')
         targets = []
         for target in targets_list:
@@ -765,9 +756,9 @@ class Traffic():
     service_name = 'ForecastService'
 
     def __init__(self,
-                 app_name: Optional[str] = APP_NAME,
-                 network_code:  Optional[str] = NETWORK_CODE,
-                 gam_version: Optional[str] = GAM_VERSION):
+                 app_name: str = APP_NAME,
+                 network_code:  str = NETWORK_CODE,
+                 gam_version: str = GAM_VERSION):
         gam_client = GamClient(app_name=app_name,
                                network_code=network_code)
         self.__gam_service = gam_client.get_service(service_name=self.service_name,
@@ -846,8 +837,8 @@ class Traffic():
         return time_series_to_list(traffic_data['historicalTimeSeries']) + time_series_to_list(traffic_data['forecastedTimeSeries'])
 
     def get_traffic_by_targeting_preset(self,
-                                        inventory_targeting=None,
-                                        targeting_preset=None,
+                                        inventory_targeting,
+                                        targeting_preset,
                                         report_date: datetime.datetime = datetime.datetime.now(
                                             tz=pytz.timezone(PYTZ_TIMEZONE)),
                                         days: int = 1) -> List[trafficItem]:
